	/*------------------------------------------------------------------------------	
	*		Project:
	*			Barbados 
	* 		Created: 	 July 16, 2018
	*		Last update: July 16, 2018
			Francisco Pardo
	* ------------------------------------------------------------------------------			

	** PURPOSE: 	This file adds the 'value added' of each assignated school type to each output variable.
					
	** INPUTS:     	

	** OUTPUTS:     

	* ----------------------------------------------------------------------------*/


	
set varabbrev on	
	

	*csec: outcomes for bssee cohorts 1987-2011
	global csec "y1 y5 y10"
	*global csec "y1"
	*global cape "z1"
	*cape: outcomes for bssee cohorts 1998-2009
	global cape "z1 z11 z9"


	
	*Schools for which program is going to be executed 
	local schools_current="schattended"
	
	local schools2_current="att"
	
	
	*Years for which program is going to be executed 
	local all_years ="0 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011"
	local current_years = "0 1988 1989 1990 1991 1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 2006 2007 2008 2009 2010 2011"
	*local current_years = "0 2002 2005"

	
	capture estimates drop *
	*Create xml files for results



use bssee_cohort $csec $cape female allocation_sch_code schattended std_bssee parish_g id_bssee rco rco2 rco3 rcoi rco2i rco3i in_sch1 c? above if bssee_cohort>1987 using "$in_diether/summary_stats.dta", clear 


forvalues i=2/5 {
	gen std_bssee_`i'=std_bssee^`i'
	}


	
save "$in_diether\individuals_va.dta", replace
use "$in_diether\individuals_va.dta", clear


* -------------------------------------------------------------------------------
** A. Validated school value-added using out of sample estimates and RD variation
* -------------------------------------------------------------------------------	


foreach i in $csec $cape {

	use "$in_diether\individuals_va.dta", clear
	
	*Only cohorts relevant to outcome
	keep if `i'!=.
	
	*--------------------------
	**	2.	FIXED EFFECTS
	*--------------------------
	

	* We compute the regression - in sample
	levelsof bssee_cohort, local(years)
	
	foreach year in `years' {
	
		use "$in_diether\individuals_va.dta", clear
		keep if `i'!=.
		
	
		if `year' != 0 {
			keep if bssee_cohort==`year'
			}
			
		if `year' == 0 {
			continue	
			}
			
		if (_N>0) {
			foreach name in `schools_current' {	
			
			preserve
				keep `i' bssee_cohort female  schattended std_bssee* parish_g id_bssee rco rco2 rco3 c? `name' above
				*
				egen `name'_year=group(`name' bssee_cohort), missing
				
				if "`name'"=="allocation_simulation" local name2="sim"
				if "`name'"=="schattended" local name2="att"
				
				*Actually first definition rco has to be done again. It uses a random cutoff since it keeps 1 observation from stack database per student. Either don't use or use the one with the actually allocated school cutoff.
				reghdfe `i' std_bssee std_bssee_2 std_bssee_3 std_bssee_4 std_bssee_5, absorb(parish_g SFX_y3=`name' c1 c2 c3 c4 c5 c6 c7 c8 c9)
				
				*estimates store s_fe_`i'_`year'_`name2'
				bysort `name': egen SFX3=mean(SFX_y3)
				bysort `name': gen index=_n
				
				keep if index==1
				keep SFX? `name' bssee_cohort
				rename SFX3 s_`name2'_fe`i'
				
				di "on year  `year' "
				save "$in_diether/s_`name'_fe`i'_`year'.dta" , replace
			restore
				
			}
		}
	}

	
	* We compute the regression - 0 year window (out of sample)
	foreach year in `years' {
	
		use "$in_diether\individuals_va.dta", clear
		keep if `i'!=.
		
		if `year' != 0 {
			gen window=abs(bssee_cohort-`year')<=0
			gen mark=1 if window==1
			di "Year `year' OOS VA estimates"
			}
			
		if `year' == 0 {
			di "Full sample VA estimates"
			gen mark=.
			}
			
			
		if (_N>0) {
			foreach name in `schools_current' {	
				preserve
					
					keep `i' bssee_cohort female  schattended std_bssee* parish_g id_bssee rco rco2 rco3 rcoi rco2i rco3i in_sch1 c? `name' above mark
					*
					egen `name'_year=group(`name' bssee_cohort), missing
					if "`name'"=="allocation_simulation" local name2="sim"
					if "`name'"=="schattended" local name2="att"
					reghdfe `i' std_bssee std_bssee_2 std_bssee_3 std_bssee_4 std_bssee_5 					if mark!=1, absorb(parish_g SFX_y3=`name' c1 c2 c3 c4 c5 c6 c7 c8 c9) 

					*estimates store s_fe_`i'_`year'_`name2'
					bysort `name': egen SFX3=mean(SFX_y3)
					bysort `name': gen index=_n
					
					keep if index==1
					keep SFX? `name'
					rename SFX3 oos_`name2'_fe`i'
					gen bssee_cohort=`year'
											
					di "on year  `year' "
					save "$in_diether/oos_`name'_fe`i'_`year'.dta" , replace

				restore
					
				}
			}
		}	
			
		
	
		*--------------------------------------------------------------------------------------------------
		**	3.	Join estimated VA for all years for outcome `i' and window 0 and given school variable
		*--------------------------------------------------------------------------------------------------
		
		foreach name in `schools_current' {
		
			clear
			set obs 1
			gen bssee_cohort=-1	
			gen `name'=-1
			foreach year of local current_years {
				
				capture append using "$in_diether/oos_`name'_fe`i'_`year'"
				capture merge 1:1 bssee_cohort `name' using "$in_diether/s_`name'_fe`i'_`year'", nogen update
					
				capture erase "$in_diether/oos_`name'_fe`i'_`year'.dta"
				capture erase "$in_diether/s_`name'_fe`i'_`year'.dta"
				*Drop initial temp observation	
				drop if bssee_cohort==-1
				}
				
			save "$in_diether/oos_`name'_`i'", replace
			}
		
		*--------------------------------------
		**	4.	SEPARATE FULL SAMPLE & OUT OF SAMPLE VA
		*--------------------------------------

		foreach samp in "oos" "full_sample" {
			foreach name in `schools_current' {
				if "`name'"=="allocation_sch_code" 		local name2="ass"
				if "`name'"=="allocation_simulation" 	local name2="sim"
				if "`name'"=="emp_ss_mr_def" 			local name2="mr"
				if "`name'"=="emp_ss_ts_def" 			local name2="ts"
				if "`name'"=="schattended" 				local name2="att"
				
				
				*Attach EB VA estimates.
				use "$in_diether/oos_`name'_`i'", clear
				
				*Label variables
				if "`name'"=="allocation_sch_code" local name3="MOE"
				if "`name'"=="schattended" local name3="School Attended"
				if "`name'"=="allocation_simulation" local name3="Simulated"
				if "`name'"=="emp_ss_mr_def" local name3="Match Rate"
				if "`name'"=="emp_ss_ts_def" local name3="T-Stat"
			
				if "`samp'"=="full_sample" {
					rename oos_`name2'_fe`i' fs_`name2'_fe`i'
					keep if bssee_cohort==0
					capture label var fs_`name2'_fe`i' "`name3' - Outcome `i' - Full sample Fixed Effects 3 - 0 year window"
					}
						
				if "`samp'"=="oos" {
					drop if bssee_cohort==0
					capture label var oos_`name2'_fe`i' "`name3' - Outcome `i' - Out of Sample Fixed Effects - 0 year window"
					capture label var s_`name2'_fe`i' "`name3' - Outcome `i' - In Sample Fixed Effects"	
					}
					
				*Rename variables
				if "`name'"=="allocation_sch_code" local name2="ass"
				if "`name'"=="allocation_simulation" local name2="sim"
				if "`name'"=="emp_ss_mr_def" local name2="mr"
				if "`name'"=="emp_ss_ts_def" local name2="ts"
				if "`name'"=="schattended" local name2="att"	

				*Drop if school is missing
				drop if `name'==.
				
				if "`samp'"=="full_sample" 	save "$in_diether/final_fs_`name'_`i'", replace
				if "`samp'"=="oos" 			save "$in_diether/final_oos_`name'_`i'", replace
				}
			}	
	}


* -------------------------------------------------------------------------------
** C. Attach all residuals
* -------------------------------------------------------------------------------
	set varabbrev off
	
	
	clear
	local obs=30*(2011-1988+1)
	set obs `obs'
	gen bssee_cohort=mod(_n,24)+1988
	sort bssee_cohort
	gen schoolcode=mod(_n,30)+1
	
	
	sort bssee_cohort schoolcode
	
	foreach name in `schools_current' {	
		foreach i in $csec $cape {
			rename schoolcode `name'
			capture merge m:1 bssee_cohort `name' using "$in_diether/final_oos_`name'_`i'", nogen
			capture merge m:1 `name' using "$in_diether/final_fs_`name'_`i'", nogen
			rename `name' schoolcode
			}
		}
	
	
	sort bssee_cohort schoolcode
	
	foreach i in $csec $cape {

		capture order fs_att_fe`i', first
		capture order oos_att_fe`i', first
		capture order s_att_fe`i', first

		}
	
	order bssee_cohort schoolcode, first

	foreach i in $csec $cape {
	
	*Teen Motherhood Outcomes
	if "`i'"=="y1" local outname="Took CSEC"
	
	if "`i'"=="z1" local outname="Took CAPE"
	
	foreach name in `schools_current' {
		*Label variables
		if "`name'"=="allocation_sch_code" local name3="MOE"
		if "`name'"=="schattended" local name3="School Attended"
		if "`name'"=="allocation_simulation" local name3="Simulated"
		if "`name'"=="emp_ss_mr_def" local name3="Match Rate"
		if "`name'"=="emp_ss_ts_def" local name3="T-Stat"

		if "`name'"=="allocation_sch_code" local name2="ass"
		if "`name'"=="allocation_simulation" local name2="sim"
		if "`name'"=="emp_ss_mr_def" local name2="mr"
		if "`name'"=="emp_ss_ts_def" local name2="ts"
		if "`name'"=="schattended" local name2="att"

		foreach k of local current_k {
				capture label var fs_`name2'_fe`i' "`name3' - #`i' : `outname' - FullSample FE 3 - 0wind"
				capture label var oos_`name2'_fe`i' "`name3' - #`i' : `outname' - OutofSample FE 3- 0wind"
				capture label var s_`name2'_fe`i' "`name3' - #`i' : `outname' - In Sample FE 3"
				

			}
		}
	}

	
	
	
	keep bssee_cohort schoolcode oos*fe* fs*fe* s*fe*

	label var bssee_cohort "BSSEE Cohort"
	label var schoolcode "Secondary School"
	
	foreach i in $csec $cape {	
		capture order  s_att_fe`i' oos_att_fe`i' fs_att_fe`i', after (last)
		}

	save "$in_diether\ValueAddeds_Factors", replace

	
*Erase databases
	foreach i in $csec $cape {
		capture erase "$in_diether/final_fs_schattended_y1.dta"
		capture erase "$in_diether/final_fs_schattended_y5.dta"
		capture erase "$in_diether/final_fs_schattended_y10.dta"
		capture erase "$in_diether/final_fs_schattended_z1.dta"
		capture erase "$in_diether/final_fs_schattended_z9.dta"
		capture erase "$in_diether/final_fs_schattended_z11.dta"
		
		capture erase "$in_diether/final_oos_schattended_y1.dta"
		capture erase "$in_diether/final_oos_schattended_y5.dta"
		capture erase "$in_diether/final_oos_schattended_y10.dta"
		capture erase "$in_diether/final_oos_schattended_z1.dta"
		capture erase "$in_diether/final_oos_schattended_z9.dta"
		capture erase "$in_diether/final_oos_schattended_z11.dta"
		
		capture erase "$in_diether/oos_schattended_y1.dta"
		capture erase "$in_diether/oos_schattended_y5.dta"
		capture erase "$in_diether/oos_schattended_y10.dta"
		capture erase "$in_diether/oos_schattended_z1.dta"
		capture erase "$in_diether/oos_schattended_z9.dta"
		capture erase "$in_diether/oos_schattended_z11.dta"
		
		capture erase "$in_diether/TEMP_y1.dta"
		capture erase "$in_diether/TEMP_y5.dta"
		capture erase "$in_diether/TEMP_y10.dta"
		capture erase "$in_diether/TEMP_z1.dta"
		capture erase "$in_diether/TEMP_z9.dta"
		capture erase "$in_diether/TEMP_z11.dta"
		
		capture erase "$in_diether\individuals_va.dta"
		
		}
	

	
	set varabbrev on

