*Set directories
clear all
set more off
global dir2 "\directory_with_databases"
global out "\directory_for_output"

cd "$dir2"


*****************************************
*Figure 2. First Stage and RD Effects
*******************************************
****************************************************
*Upper Panel. RD Effects on Attending a Preferred School and CSEC Certificate
****************************************************

*Attended preferred school

*This database contains the stacked database described in Section IV of the main text 
*please refer to the instructions document for details on how to request access to the database
use "BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
replace bins_2=bins_1

keep if bins_2>=-20 & bins_2<=20

foreach x in in_sch1 {
	qui reg in_sch1 rco rco2 rco3 rcoi rco2i rco3i above, cl (id_bssee) 
	predict p_u_`x' if e(sample)
	predict error  if e(sample), stdp
	generate p_u_lbp5_`x'=p_u_`x'-invt(e(df_r),0.975)*error
	generate p_u_ubp5_`x'=p_u_`x'+invt(e(df_r),0.975)*error
	generate p_u_lbp10_`x'=p_u_`x'-invt(e(df_r),0.95)*error
	generate p_u_ubp10_`x'=p_u_`x'+invt(e(df_r),0.95)*error	
	drop error
	}

collapse (mean) in_sch1 p_u_* rco  (count) num=rco, by(bins_2) 

gen b=rco<0
gen a=rco>=0

foreach x in in_sch1 {
	gen a_p_u_`x'=p_u_`x'*a
	replace a_p_u_`x'=. if a==0
	gen b_p_u_`x'=p_u_`x'*b
	replace b_p_u_`x'=. if b==0
**ADDED CODE (2)
	*Prediction interval:
	*-Lower bound 5%
	gen a_p_u_lbp5_`x'=p_u_lbp5_`x'*a
	replace a_p_u_lbp5_`x'=. if a==0
	gen b_p_u_lbp5_`x'=p_u_lbp5_`x'*b
	replace b_p_u_lbp5_`x'=. if b==0
	*-Upper bound 5%
	gen a_p_u_ubp5_`x'=p_u_ubp5_`x'*a
	replace a_p_u_ubp5_`x'=. if a==0
	gen b_p_u_ubp5_`x'=p_u_ubp5_`x'*b
	replace b_p_u_ubp5_`x'=. if b==0
		
	*-Lower bound 10%
	gen a_p_u_lbp10_`x'=p_u_lbp10_`x'*a
	replace a_p_u_lbp10_`x'=. if a==0
	gen b_p_u_lbp10_`x'=p_u_lbp10_`x'*b
	replace b_p_u_lbp10_`x'=. if b==0
	*-Upper bound 10%
	gen a_p_u_ubp10_`x'=p_u_ubp10_`x'*a
	replace a_p_u_ubp10_`x'=. if a==0
	gen b_p_u_ubp10_`x'=p_u_ubp10_`x'*b
	replace b_p_u_ubp10_`x'=. if b==0
	}	

label var bins_2 "Score minus school cutoff" 


foreach x in "in_sch1" {
	graph tw 	(rarea  a_p_u_lbp5_`x' a_p_u_ubp5_`x' bins_2 , astyle(ci) fcolor(gs13)) ///
				(rarea  a_p_u_lbp10_`x' a_p_u_ubp10_`x' bins_2 , astyle(ci) fcolor(gs11)) ///
				(rarea  b_p_u_lbp5_`x' b_p_u_ubp5_`x' bins_2 , astyle(ci) fcolor(gs13)) ///
				(rarea  b_p_u_lbp10_`x' b_p_u_ubp10_`x' bins_2 , astyle(ci) fcolor(gs11)) ///
				(scatter in_sch1 a_p_u_`x' b_p_u_`x' a_p_u_lbp5_`x' b_p_u_lbp5_`x' a_p_u_ubp5_`x' b_p_u_ubp5_`x' a_p_u_lbp10_`x' b_p_u_lbp10_`x' a_p_u_ubp10_`x' b_p_u_ubp10_`x'  bins_2,	ms(Oh i i i i i i i i i i) c(i l l l l l l l l l l) mcolor(black black black gs9 gs9 gs9 gs9 gs9 gs9 gs9 gs9) lcolor(black black black gs9 gs9 gs9 gs9 gs9 gs9 gs9 gs9) lwidth(thin medthick medthick vvthin vvthin vvthin vvthin vvthin vvthin vvthin vvthin)) ///
			,	xline(0, lstyle(foreground) lpattern(dash) lcolor(black)) ///
				ytitle("")  legend(off) ///
				xlabel(-20(4)20) ylabel(, labsize(small) angle(horizontal)) xtitle() subtitle("At Preferred School (Age 11)") graphregion(color(white)) bgcolor(white) ///
				saving("$out\\`x'.gph", replace)	
		}



*CSEC certificate (passed secondary school exam)
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

**Look at effects using cohorts for which full CAPE data is available (bssee_cohort>=1998 & bssee_cohort<=2009); +/- 0.75 SD from cutoff 
keep if rco>=-23&rco<=23&(rco~=0)&(bssee_cohort>=1998 & bssee_cohort<=2009)
replace bins_2=bins_1

*Controlling for cutoff FE, parish Fe and  preferences 
  foreach x in "y10" {
qui reghdfe `x' , absorb( fixed_effect parish_g c1 c2 c3 c4 c5 c6 c7 c8 c9)  residuals(u_`x')
 }
 

foreach x in "y10"{
	qui reg u_`x' rco rco2 rco3 rcoi rco2i rco3i above 
	predict p_u_`x' if e(sample)

	***ADDED CODE (1)
	*Confidence interval: uses lower and upper bounds from coefficients. Can go to zero if estimation of coefficients gets more precise.
	mat A = r(table)
	gen p_u_lbc_`x' = 0
	gen p_u_ubc_`x' = 0
	gen cons=1
	local covariates "rco rco2 rco3 rcoi rco2i rco3i above cons"
	local i=1
	foreach cov in `covariates'{
		replace p_u_lbc_`x' = p_u_lbc_`x' +  A[5,`i']*`cov'
		replace p_u_ubc_`x' = p_u_ubc_`x' +  A[6,`i']*`cov'
		local i=`i'+1
		}
	drop cons

	*Prediction interval: uses std error of predicted outcome. Will not go to zero because of natural error term.
	predict error  if e(sample), stdp
	generate p_u_lbp5_`x'=p_u_`x'-invt(e(df_r),0.975)*error
	generate p_u_ubp5_`x'=p_u_`x'+invt(e(df_r),0.975)*error
	generate p_u_lbp10_`x'=p_u_`x'-invt(e(df_r),0.95)*error
	generate p_u_ubp10_`x'=p_u_`x'+invt(e(df_r),0.95)*error	
	drop error
	****//(1)
	}

keep if bins_2>=-20 & bins_2<=20

collapse (mean)   u_* p_u_* rco (count) num=rco, by(bins_2) 

gen b=rco<0
gen a=rco>=0


foreach x in "y10"{
	gen a_p_u_`x'=p_u_`x'*a
	replace a_p_u_`x'=. if a==0
	gen b_p_u_`x'=p_u_`x'*b
	replace b_p_u_`x'=. if b==0
**ADDED CODE (2)
	*Confidence interval:
	*-Lower bound
	gen a_p_u_lbc_`x'=p_u_lbc_`x'*a
	replace a_p_u_lbc_`x'=. if a==0
	gen b_p_u_lbc_`x'=p_u_lbc_`x'*b
	replace b_p_u_lbc_`x'=. if b==0
	*-Upper bound
	gen a_p_u_ubc_`x'=p_u_ubc_`x'*a
	replace a_p_u_ubc_`x'=. if a==0
	gen b_p_u_ubc_`x'=p_u_ubc_`x'*b
	replace b_p_u_ubc_`x'=. if b==0

	*Prediction interval:
	*-Lower bound 5%
	gen a_p_u_lbp5_`x'=p_u_lbp5_`x'*a
	replace a_p_u_lbp5_`x'=. if a==0
	gen b_p_u_lbp5_`x'=p_u_lbp5_`x'*b
	replace b_p_u_lbp5_`x'=. if b==0
	*-Upper bound 5%
	gen a_p_u_ubp5_`x'=p_u_ubp5_`x'*a
	replace a_p_u_ubp5_`x'=. if a==0
	gen b_p_u_ubp5_`x'=p_u_ubp5_`x'*b
	replace b_p_u_ubp5_`x'=. if b==0
		
	*-Lower bound 10%
	gen a_p_u_lbp10_`x'=p_u_lbp10_`x'*a
	replace a_p_u_lbp10_`x'=. if a==0
	gen b_p_u_lbp10_`x'=p_u_lbp10_`x'*b
	replace b_p_u_lbp10_`x'=. if b==0
	*-Upper bound 10%
	gen a_p_u_ubp10_`x'=p_u_ubp10_`x'*a
	replace a_p_u_ubp10_`x'=. if a==0
	gen b_p_u_ubp10_`x'=p_u_ubp10_`x'*b
	replace b_p_u_ubp10_`x'=. if b==0
	}	
**//(2)

	label var bins_2 "Score minus school cutoff" 


**ADDED CODE (3)
	foreach x in "y10" {
		graph tw 	(rarea  a_p_u_lbp5_`x' a_p_u_ubp5_`x' bins_2 , astyle(ci) fcolor(gs13)) ///
					(rarea  a_p_u_lbp10_`x' a_p_u_ubp10_`x' bins_2 , astyle(ci) fcolor(gs11)) ///
					(rarea  b_p_u_lbp5_`x' b_p_u_ubp5_`x' bins_2 , astyle(ci) fcolor(gs13)) ///
					(rarea  b_p_u_lbp10_`x' b_p_u_ubp10_`x' bins_2 , astyle(ci) fcolor(gs11)) ///
					(scatter u_`x' a_p_u_`x' b_p_u_`x' a_p_u_lbp5_`x' b_p_u_lbp5_`x' a_p_u_ubp5_`x' b_p_u_ubp5_`x' a_p_u_lbp10_`x' b_p_u_lbp10_`x' a_p_u_ubp10_`x' b_p_u_ubp10_`x'  bins_2,	ms(Oh i i i i i i i i i i) c(i l l l l l l l l l l) mcolor(black black black gs9 gs9 gs9 gs9 gs9 gs9 gs9 gs9) lcolor(black black black gs9 gs9 gs9 gs9 gs9 gs9 gs9 gs9) lwidth(thin medthick medthick vvthin vvthin vvthin vvthin vvthin vvthin vvthin vvthin)) ///
				,	xline(0, lstyle(foreground) lpattern(dash) lcolor(black)) ///
					ytitle("")  legend(off) ///
					xlabel(-20(4)20) ylabel(, labsize(small) angle(horizontal)) xtitle() subtitle("Passed Secondary School Exam (Age 16)") graphregion(color(white)) bgcolor(white) ///
					saving("$out\\`x'.gph", replace)	 	
		
				
		}		
**//(3)

gr combine "$out\in_sch1.gph" "$out\y10.gph"  , graphregion(color(white)) saving("$out\fig2_final_up.gph", replace)     


****************************************************
*Lower panel. RD Effects on CAPE and Long-Term Index 
****************************************************
*CAPE Associate
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

**Look at effects using cohorts for which full CAPE data is available (bssee_cohort>=1998 & bssee_cohort<=2009); +/- 0.75 SD from cutoff 
keep if rco>=-23&rco<=23&(rco~=0)&(bssee_cohort>=1998 & bssee_cohort<=2009)
replace bins_2=bins_1

*Controlling for cutoff FE, parish Fe and  preferences 
foreach x in "z9"{
	qui reghdfe `x' , absorb( fixed_effect parish_g c1 c2 c3 c4 c5 c6 c7 c8 c9)  residuals(u_`x')
	}


 *if abs(bins_2)<=16
foreach x in "z9"{
	qui reg u_`x' rco rco2 rco3 rcoi rco2i rco3i above 
	predict p_u_`x' if e(sample)
	
	***ADDED CODE (1)
	*Confidence interval: uses lower and upper bounds from coefficients. Can go to zero if estimation of coefficients gets more precise.
	mat A = r(table)
	gen p_u_lbc_`x' = 0
	gen p_u_ubc_`x' = 0
	gen cons=1
	local covariates "rco rco2 rco3 rcoi rco2i rco3i above cons"
	local i=1
	foreach cov in `covariates'{
		replace p_u_lbc_`x' = p_u_lbc_`x' +  A[5,`i']*`cov'
		replace p_u_ubc_`x' = p_u_ubc_`x' +  A[6,`i']*`cov'
		local i=`i'+1
		}
	drop cons

	*Prediction interval: uses std error of predicted outcome. Will not go to zero because of natural error term.
	predict error  if e(sample), stdp
	generate p_u_lbp5_`x'=p_u_`x'-invt(e(df_r),0.975)*error
	generate p_u_ubp5_`x'=p_u_`x'+invt(e(df_r),0.975)*error
	generate p_u_lbp10_`x'=p_u_`x'-invt(e(df_r),0.95)*error
	generate p_u_ubp10_`x'=p_u_`x'+invt(e(df_r),0.95)*error	
	drop error
	****//(1)
	}

keep if bins_2>=-20 & bins_2<=20

collapse (mean)   u_* p_u_* rco (count) num=rco, by(bins_2) 

gen b=rco<0
gen a=rco>=0

foreach x in "z9"{
	gen a_p_u_`x'=p_u_`x'*a
	replace a_p_u_`x'=. if a==0
	gen b_p_u_`x'=p_u_`x'*b
	replace b_p_u_`x'=. if b==0
**ADDED CODE (2)
	*Confidence interval:
	*-Lower bound
	gen a_p_u_lbc_`x'=p_u_lbc_`x'*a
	replace a_p_u_lbc_`x'=. if a==0
	gen b_p_u_lbc_`x'=p_u_lbc_`x'*b
	replace b_p_u_lbc_`x'=. if b==0
	*-Upper bound
	gen a_p_u_ubc_`x'=p_u_ubc_`x'*a
	replace a_p_u_ubc_`x'=. if a==0
	gen b_p_u_ubc_`x'=p_u_ubc_`x'*b
	replace b_p_u_ubc_`x'=. if b==0

	*Prediction interval:
	*-Lower bound 5%
	gen a_p_u_lbp5_`x'=p_u_lbp5_`x'*a
	replace a_p_u_lbp5_`x'=. if a==0
	gen b_p_u_lbp5_`x'=p_u_lbp5_`x'*b
	replace b_p_u_lbp5_`x'=. if b==0
	*-Upper bound 5%
	gen a_p_u_ubp5_`x'=p_u_ubp5_`x'*a
	replace a_p_u_ubp5_`x'=. if a==0
	gen b_p_u_ubp5_`x'=p_u_ubp5_`x'*b
	replace b_p_u_ubp5_`x'=. if b==0
		
	*-Lower bound 10%
	gen a_p_u_lbp10_`x'=p_u_lbp10_`x'*a
	replace a_p_u_lbp10_`x'=. if a==0
	gen b_p_u_lbp10_`x'=p_u_lbp10_`x'*b
	replace b_p_u_lbp10_`x'=. if b==0
	*-Upper bound 10%
	gen a_p_u_ubp10_`x'=p_u_ubp10_`x'*a
	replace a_p_u_ubp10_`x'=. if a==0
	gen b_p_u_ubp10_`x'=p_u_ubp10_`x'*b
	replace b_p_u_ubp10_`x'=. if b==0
	}	
**//(2)	

	label var bins_2 "Score minus school cutoff" 


**ADDED CODE (3)
	foreach x in "z9" {
		graph tw 	(rarea  a_p_u_lbp5_`x' a_p_u_ubp5_`x' bins_2 , astyle(ci) fcolor(gs13)) ///
					(rarea  a_p_u_lbp10_`x' a_p_u_ubp10_`x' bins_2 , astyle(ci) fcolor(gs11)) ///
					(rarea  b_p_u_lbp5_`x' b_p_u_ubp5_`x' bins_2 , astyle(ci) fcolor(gs13)) ///
					(rarea  b_p_u_lbp10_`x' b_p_u_ubp10_`x' bins_2 , astyle(ci) fcolor(gs11)) ///
					(scatter u_`x' a_p_u_`x' b_p_u_`x' a_p_u_lbp5_`x' b_p_u_lbp5_`x' a_p_u_ubp5_`x' b_p_u_ubp5_`x' a_p_u_lbp10_`x' b_p_u_lbp10_`x' a_p_u_ubp10_`x' b_p_u_ubp10_`x'  bins_2,	ms(Oh i i i i i i i i i i) c(i l l l l l l l l l l)  mcolor(black black black gs9 gs9 gs9 gs9 gs9 gs9 gs9 gs9) lcolor(black black black gs9 gs9 gs9 gs9 gs9 gs9 gs9 gs9) lwidth(thin medthick medthick vvthin vvthin vvthin vvthin vvthin vvthin vvthin vvthin)) ///
				,	xline(0, lstyle(foreground) lpattern(dash) lcolor(black)) ///
					ytitle("")  legend(off) ///
					xlabel(-20(4)20) ylabel(, labsize(small) angle(horizontal)) xtitle() subtitle("Earned CAPE Associate's Degree (Age 18)") graphregion(color(white)) bgcolor(white) ///
					saving("$out\\`x'.gph", replace)	 	
		
	 	
		}	


*Long-Term Index
*Controlling for cutoff FE, parish Fe and first 4 preferences

  foreach y in  "long_sd"  {

use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
replace bins_2=bins_1
keep if face_bslc==1&bssee_cohort<2003

 
  foreach x in "`y'"{
qui reghdfe `x' [pw= weight], absorb( fixed_effect parish_g  c1 c2 c3 c4 )  residuals(u_`x')
 }


foreach x in "`y'" {
	qui reg u_`x' rco rco2 rco3 rcoi rco2i rco3i above 
	predict p_u_`x' if e(sample)
	***ADDED CODE (1)
		*Confidence interval: uses lower and upper bounds from coefficients. Can go to zero if estimation of coefficients gets more precise.
		mat A = r(table)
		gen p_u_lbc_`x' = 0
		gen p_u_ubc_`x' = 0
		gen cons=1
		local covariates "rco rco2 rco3 rcoi rco2i rco3i above cons"
		local i=1
		foreach cov in `covariates'{
			replace p_u_lbc_`x' = p_u_lbc_`x' +  A[5,`i']*`cov'
			replace p_u_ubc_`x' = p_u_ubc_`x' +  A[6,`i']*`cov'
			local i=`i'+1
			}
		drop cons

		*Prediction interval: uses std error of predicted outcome. Will not go to zero because of natural error term.
		predict error  if e(sample), stdp
		generate p_u_lbp5_`x'=p_u_`x'-invt(e(df_r),0.975)*error
		generate p_u_ubp5_`x'=p_u_`x'+invt(e(df_r),0.975)*error
		generate p_u_lbp10_`x'=p_u_`x'-invt(e(df_r),0.95)*error
		generate p_u_ubp10_`x'=p_u_`x'+invt(e(df_r),0.95)*error
		drop error
		****//(1)
	}

keep if bins_2>=-20 & bins_2<=20


collapse (mean)   u_* p_u_* rco (count) num=rco, by(bins_2) 

gen b=rco<0
gen a=rco>=0

foreach x in "`y'" {
	gen a_p_u_`x'=p_u_`x'*a
	replace a_p_u_`x'=. if a==0
	gen b_p_u_`x'=p_u_`x'*b
	replace b_p_u_`x'=. if b==0
**ADDED CODE (2)
	*Confidence interval:
	*-Lower bound
	gen a_p_u_lbc_`x'=p_u_lbc_`x'*a
	replace a_p_u_lbc_`x'=. if a==0
	gen b_p_u_lbc_`x'=p_u_lbc_`x'*b
	replace b_p_u_lbc_`x'=. if b==0
	*-Upper bound
	gen a_p_u_ubc_`x'=p_u_ubc_`x'*a
	replace a_p_u_ubc_`x'=. if a==0
	gen b_p_u_ubc_`x'=p_u_ubc_`x'*b
	replace b_p_u_ubc_`x'=. if b==0

	*Prediction interval:
	*-Lower bound 5%
	gen a_p_u_lbp5_`x'=p_u_lbp5_`x'*a
	replace a_p_u_lbp5_`x'=. if a==0
	gen b_p_u_lbp5_`x'=p_u_lbp5_`x'*b
	replace b_p_u_lbp5_`x'=. if b==0
	*-Upper bound 5%
	gen a_p_u_ubp5_`x'=p_u_ubp5_`x'*a
	replace a_p_u_ubp5_`x'=. if a==0
	gen b_p_u_ubp5_`x'=p_u_ubp5_`x'*b
	replace b_p_u_ubp5_`x'=. if b==0
		
	*-Lower bound 10%
	gen a_p_u_lbp10_`x'=p_u_lbp10_`x'*a
	replace a_p_u_lbp10_`x'=. if a==0
	gen b_p_u_lbp10_`x'=p_u_lbp10_`x'*b
	replace b_p_u_lbp10_`x'=. if b==0
	*-Upper bound 10%
	gen a_p_u_ubp10_`x'=p_u_ubp10_`x'*a
	replace a_p_u_ubp10_`x'=. if a==0
	gen b_p_u_ubp10_`x'=p_u_ubp10_`x'*b
	replace b_p_u_ubp10_`x'=. if b==0
	}		
**//(2)

	label var bins_2 "Score minus school cutoff" 
	

	
	collapse (mean)   u_* p_u_* a_p_u_* b_p_u_* rco (count) num=rco, by(bins_2) 

	
**ADDED CODE (3)
	foreach x in "`y'" {
		graph tw 	(rarea  a_p_u_lbp5_`x' a_p_u_ubp5_`x' bins_2 , astyle(ci) fcolor(gs13)) ///
					(rarea  a_p_u_lbp10_`x' a_p_u_ubp10_`x' bins_2 , astyle(ci) fcolor(gs11)) ///
					(rarea  b_p_u_lbp5_`x' b_p_u_ubp5_`x' bins_2 , astyle(ci) fcolor(gs13)) ///
					(rarea  b_p_u_lbp10_`x' b_p_u_ubp10_`x' bins_2 , astyle(ci) fcolor(gs11)) ///
					(scatter u_`x' a_p_u_`x' b_p_u_`x' a_p_u_lbp5_`x' b_p_u_lbp5_`x' a_p_u_ubp5_`x' b_p_u_ubp5_`x' a_p_u_lbp10_`x' b_p_u_lbp10_`x' a_p_u_ubp10_`x' b_p_u_ubp10_`x'  bins_2,	ms(Oh i i i i i i i i i i) c(i l l l l l l l l l l)  mcolor(black black black gs9 gs9 gs9 gs9 gs9 gs9 gs9 gs9) lcolor(black black black gs9 gs9 gs9 gs9 gs9 gs9 gs9 gs9) lwidth(thin medthick medthick vvthin vvthin vvthin vvthin vvthin vvthin vvthin vvthin)) ///
				,	xline(0, lstyle(foreground) lpattern(dash) lcolor(black)) ///
					ytitle("")  legend(off) ///
					xlabel(-20(4)20) ylabel(-0.05(.05)0.3, grid) ylabel(, labsize(small) angle(horizontal)) xtitle() subtitle("Long-Term Index (Ages 25-40)") graphregion(color(white)) bgcolor(white) ///
					saving("$out\\`x'_all.gph", replace)	 	
		

		}	
}
	

gr combine "$out\z9.gph" "$out\long_sd_all.gph"  , graphregion(color(white)) saving("$out\fig2_final_low.gph", replace)     
		

*combining
gr combine "$out\fig2_final_up.gph" "$out\fig2_final_low.gph", graphregion(color(white))  col(1) saving("$out\Figure2_final.gph", replace)    

capture qui graph export "$out\Figure2_final.png", replace


*****************************************
* Appendix Figures
*******************************************

****************************************
*Appendix Figure A1. 2SLS Effects by Bandwidth
****************************************
forval x=1/4{
clear all
save $dir2\CI\CI_`x', replace emptyok
}
****************************************
*CSEC certificate and CAPE associate
****************************************

cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 


**Look at effects using cohorts for which full CAPE data is available (bssee_cohort>=1998 & bssee_cohort<=2009) 
keep if (bssee_cohort>=1998 & bssee_cohort<=2009)

local i=1
	foreach out in "y10" "z9" {
	
			forval x=10/80{
			preserve
				qui reghdfe `out' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if rco>=-`x'&rco<=`x'&(rco~=0)  , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)

				
				local c_5 = invt(e(df_r),0.975)
				local c_10 = invt(e(df_r),0.95)
				
				local b =  _b[in_sch1]
				local se =  _se[in_sch1]
				local ll_5 = `b' - `c_5'*`se'
				local ul_5 = `b' + `c_5'*`se'
				local ll_10 = `b' - `c_10'*`se'
				local ul_10 = `b' + `c_10'*`se'
				
				clear
				set obs 1

				gen b = `b'
				gen ll_5 = `ll_5' 
				gen ul_5 = `ul_5'
				gen ll_10 = `ll_10' 
				gen ul_10 = `ul_10'

				gen x = `x'  

				append using "$dir2\CI\CI_`i'"
				save "$dir2\CI\CI_`i'", replace
				
			restore
			}
		local i=`i'+1
		}	
	
****************************************
*long-term index + social networks
****************************************

cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

*Ages ~25-40 when surveyed

keep if face_bslc==1 & bssee_cohort<2003 

local i=3
foreach out in "long_sd" "q9_26c" {
	forval x=15/60{
		preserve
			if `x'!=60 qui reghdfe `out'  rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if rco>=-`x'&rco<=`x' [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4) cluster(id_bssee)
			if `x'==60 qui reghdfe `out'  rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4) cluster(id_bssee)

			local c_5 = invt(e(df_r),0.975)
			local c_10 = invt(e(df_r),0.95)
			
			local b =  _b[in_sch1]
			local se =  _se[in_sch1]
			local ll_5 = `b' - `c_5'*`se'
			local ul_5 = `b' + `c_5'*`se'
			local ll_10 = `b' - `c_10'*`se'
			local ul_10 = `b' + `c_10'*`se'
			
			clear
			set obs 1

			gen b = `b'
			gen ll_5 = `ll_5' 
			gen ul_5 = `ul_5'
			gen ll_10 = `ll_10' 
			gen ul_10 = `ul_10'

			gen x = `x' 

			if `x'==60 gen type = "all"

			
			append using "$dir2\CI\CI_`i'"
			save "$dir2\CI\CI_`i'", replace
			
		restore
		}
		local i=`i'+1
	}
		


*Graphs 
foreach i in "1" "2" "3" "4"  {	
	if `i' == 1 local title = "Passed Secondary School Exam (Age 16)"
	if `i' == 2 local title = "Earned CAPE Associate's Degree (Age 18)"
	if `i' == 3 local title = "Long-Term Index (Ages 25-40)"	
	if `i' == 4 local title = "Referred by School Network (Ages 25-40)"

	
	use "$dir2\CI\CI_`i'", clear
	if `i' >=3 drop if x==60 & type!="all"
	keep if x>=15 & x<=60
	 twoway (rarea  ll_5 ul_5 x , astyle(ci) fcolor(gs13)) ///
			(rarea  ll_10 ul_10 x , astyle(ci) fcolor(gs11)) ///
		   (line b ul_5 ll_5 ul_10 ll_10 x, lcolor(black black black black black ) lwidth(thick vvthin vvthin vvthin vvthin))  ///
		   (function y=0, range(15 60)  lcolor(black)), ///
			xtitle(Bandwidth) ///
			subtitle("`title'") ///
		   legend(off) ///
		   graphregion(fcolor(white)) ///
		   xlabel(15(5)60) ///
		   name(rarea, replace) 
	graph save "$out\CI_`i'.gph" , replace		 
	
	}	


gr combine "$out\CI_1.gph"  "$out\CI_2.gph", graphregion(color(white)) saving("$out\sensitivity_up.gph", replace)     
gr combine "$out\CI_3.gph"  "$out\CI_4.gph", graphregion(color(white)) saving("$out\sensitivity_low.gph", replace)     

gr combine "$out\sensitivity_up.gph" "$out\sensitivity_low.gph", graphregion(color(white))  col(1) saving("$out\Figure_A1.gph", replace)    
capture qui graph export "$out\Figure_A1.png", replace


****************************************
*Appendix Figure A2. Cutoff Falsification Test (Long-Term Index)
****************************************
set seed 1

clear 
save "$dir2/coefs.dta", emptyok replace


cd "$dir2"
use long_sd rco rco2 rco3 rcoi rco2i rco3i in_sch1 above face_bslc weight parish_g fixed_effect c1 c2 c3 c4 id_bssee bssee_cohort total_conv  using "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
keep if face_bslc==1 & bssee_cohort<2003 

forvalues i = 1/2000 {
	preserve
		drop rco rco2 rco3 rcoi rco2i rco3i above

		bys fixed_effect: gen u = runiform() if _n==1
		bys fixed_effect: egen u2 = max(u)
		bys fixed_effect: egen min = min(total_conv)
		bys fixed_effect: egen max = max(total_conv)
		gen f_cutoff = (max - min) * u2 + min

		gen rco=total_conv- f_cutoff
		gen above=rco>=0
		gen rco2= rco*rco
		gen rco3 = rco2*rco
		gen rcoi=rco*above
		gen rco2i= rco2*above
		gen rco3i = rco3*above

		reghdfe long_sd rco rco2 rco3 rcoi rco2i rco3i above if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee )
		local b=_b[above]
		local se=_se[above]
		
		di `b'
		di `se'

		clear
		set obs 1
		gen b=`b'
		gen se = `se' 
		append using "$dir2/coefs.dta"
		save "$dir2/coefs.dta", replace

	restore
	}
	
	

use "$dir2/coefs.dta", clear
label var b "Placebo reduced-form effects"
kdensity b,	xaxis(1 2) xli(0.147) xla(0.147 "Real effect = 0.147", axis(2)) xtitle("", axis(2)) xla(-.1(0.05)0.20, axis(1)) legend(off) note("") title("") graphregion(fcolor(white)) ytitle("") ylabel(0(2)12, grid)  saving ("$out\Figure_A2.gph", replace)
capture qui graph export "$out\Figure_A2.png", replace
clear



*****************************************
*Appendix Figure C1. School Choices
*******************************************
*This database contains one observation per student will all administrative and matched survey data 
*including school aplications, choices, examinations and survey information
*please refer to the instructions document for details on how to request access to the database
use summary_stats.dta, clear

* use the top 9 choices to get a revealed preferences ranking
keep id_bssee c1 c2 c3 c4 c5 c6 c7 c8 c9  bssee_cohort
reshape long c , i(id_bssee) j(choice)
save barbados_test.dta, replace

foreach  y in 1987 2011 {

use barbados_test.dta, clear
keep if bssee_cohort==`y'
egen schoolID=group(c)
xi: rologit choice i.schoolID , group(id_bssee)

sum schoolID 
local max=r(max)

gen logit=.
replace logit=0 if schoolID==1
forvalues c = 2/`max' {
replace logit= _b[_IschoolID_`c'] if schoolID==`c'
} 
collapse (mean) logit , by(c)
egen rank_`y' =rank(logit)
rename logit logit_`y'
save barbados_rank_`y', replace
}

use barbados_rank_1987.dta , clear
foreach  y in  2011 {
merge 1:1 c using barbados_rank_`y'.dta , nogen
}

*drop missing schools (99) and parents who chose bursaries for private schools instead of a public school (4)
drop if c==99
drop if c==4

label variable rank_1987 "School rank 1987"
label variable rank_2011 "School rank 2011"


twoway (scatter rank_2011 rank_1987 , mlabel(c)), graphregion(color(white)) saving(s1987_2011.gph, replace) subtitle("School Rankings Across Cohorts")		


corr logit_1987 logit_2011
/*
              | log~1987 log~2011
-------------+------------------
  logit_1987 |   1.0000
  logit_2011 |   0.9181   1.0000

*/
  
  
corr rank_1987 rank_2011

/*
              | ran~1987 ran~2011
-------------+------------------
   rank_1987 |   1.0000
   rank_2011 |   0.9557   1.0000

*/

reg rank_2011 rank_1987
test rank_1987==1

use summary_stats.dta, clear

*Full population
forval x=1/9 {
sort peer_score_c`x'
cumul peer_score_c`x', gen(cum`x') equal
}

local z1 cum1 peer_score_c1
local z2 cum2 peer_score_c2 
local z3 cum3 peer_score_c3 
local z4 cum4 peer_score_c4 
local z5 cum5 peer_score_c5 
local z6 cum6 peer_score_c6 
local z7 cum7 peer_score_c7 
local z8 cum8 peer_score_c8 
local z9 cum9 peer_score_c9 


tw (line `z1', lwidth(vvthin) lstyle(p1)lpattern(solid) lcolor(black) sort) ///
(line `z2', lwidth(vvthin) lstyle(p1)lpattern(dash) lcolor(black) sort) ///
(line `z3', lwidth(vvthin) lstyle(p1)lpattern(solid) lcolor(black) sort) ///
(line `z4', lwidth(vvthin) lstyle(p1)lpattern(dash) lcolor(black) sort) ///
(line `z5', lwidth(vvthin) lstyle(p1)lpattern(ddot) lcolor(black) sort) ///
(line `z6', lwidth(vvthin) lstyle(p1)lpattern(shortdash_dot) lcolor(black) sort) ///
(line `z7', lwidth(vvthin) lstyle(p1)lpattern(ddot) lcolor(black) sort) ///
(line `z8', lwidth(vvthin) lstyle(p1)lpattern(shortdash_dot) lcolor(black) sort) ///
(line `z9', lwidth(vvthin) lstyle(p1)lpattern(solid) lcolor(black) sort) ///
pci 0.63 1.65 0.63 1.5 "Top", lcolor(black)  mlabcolor(black) recast(pccapsym) msymbol(i) || pci 0.54 1.55 0.54 1.25 "Second", lcolor(black)  mlabcolor(black) recast(pccapsym) msymbol(i) || pci 0.47 1.45 0.47 1.03 "Third", lcolor(black)  mlabcolor(black) recast(pccapsym) msymbol(i) || pci 0.3 1.35 0.3 0.4 "Fourth", lcolor(black)  mlabcolor(black) recast(pccapsym) msymbol(i) || pci 0.78 -0.9 0.78 0.85 "Fifth",lcolor(black)   mlabposition(9) mlabcolor(black) recast(pccapsym) msymbol(i) || pci 0.66 -1.2 0.66 0.43 "Sixth", lcolor(black)  mlabposition(9) mlabcolor(black) recast(pccapsym) msymbol(i) || pci 0.54 -1.24 0.54 -0.165 "Seventh", lcolor(black)  mlabposition(9) mlabcolor(black) recast(pccapsym) msymbol(i) || pci 0.42 -1.37 0.42 -0.66 "Eighth", lcolor(black)  mlabposition(9) mlabcolor(black) recast(pccapsym) msymbol(i)  || pci 0.3 -1.45 0.3 -1.1 "Ninth", lcolor(black)  mlabposition(9) mlabcolor(black) recast(pccapsym) msymbol(i) ///
   subtitle("Incoming Peer Achievement by School Choice") xtitle("Mean standardized score of school choice") xlabel(, labsize(small)) ///
   ytitle("Empirical cumulative density") ylabel(0 (0.2)1, grid gmax angle(horizontal)) ///
   legend(off) graphregion(color(white)) saving(peers_pref_all.gph, replace)

gr combine s1987_2011.gph  peers_pref_all.gph, graphregion(color(white)) saving("$out\Figure_C1.gph", replace)     
capture qui graph export "$out\Figure_C1.png", replace


