*Set directories
clear all
set more off
global dir2 "\directory"
cd "$dir2"


*****************************************
* Get overall ranking of schools by incoming peer BSSEE scores
*******************************************
*This database contains one observation per student will all administrative data 
*please refer to the instructions document for details on how to request access to the database

use "$dir2/BSSEE_CSEC_CAPE_BARBADOS.dta", clear
*define standardized score by cohort
foreach x in total_conv {
bysort bssee_cohort: egen mean_`x'=mean(`x')
bysort bssee_cohort: egen sd_`x'=sd(`x')
gen peer_score_st=(`x'-mean_`x')/sd_`x'
}
collapse (mean) peer_score_st, by (csec_secondary_sch_code1)
gsort  -peer_score_st
gen ranking1 =_n
save "$dir2/ranking1.dta", replace
clear



***********************************************************************************
*Table 1: Summary Statistics 
***********************************************************************************
*This database contains one observation per student will all administrative and matched survey data 
*including school aplications, choices, examinations and survey information
*please refer to the instructions document for details on how to request access to the database
use "$dir2/summary_stats.dta", clear


*Administrative Data

joinby csec_secondary_sch_code1 using "$dir2/ranking1.dta", unm(m)
gen g1=ranking1>=1&ranking1<=8
gen g2=ranking1>=9&ranking1<=16
gen g3=ranking1>=17

*calculate means for administrative data
!erase summ.xls
!erase summ.txt 
foreach x in std_bssee female y1  y10 z1   z9 {
qui reg `x' 
outreg2  using summ,  excel dec(3)  noaster append
qui reg `x' if g1==1
outreg2  using summ,  excel dec(3)  noaster append
qui reg `x' if g2==1
outreg2  using summ,  excel dec(3)  noaster append
qui reg `x' if g3==1
outreg2  using summ,  excel dec(3)  noaster append
}

*calculate standard deviations for administrative data
preserve
collapse (sd) std_bssee female y1  y10 z1   z9
save sum1.dta, replace
restore

preserve
keep if g1==1
collapse (sd) std_bssee female y1  y10 z1   z9
save sum2.dta, replace
restore

preserve
keep if g2==1
collapse (sd) std_bssee female y1  y10 z1   z9
save sum3.dta, replace
restore

preserve
keep if g3==1
collapse (sd) std_bssee female y1  y10 z1   z9
save sum4.dta, replace
restore

*Calculate cohort sizes by school
gen size=1
drop if csec_secondary_sch_code1==99
drop if csec_secondary_sch_code1==4
collapse (sum) size, by (bssee_cohort csec_secondary_sch_code1 ranking1)

*Calculate average school cohort sizes
!erase summ1.xls
!erase summ1.txt 
gen g1=ranking1>=1&ranking1<=8
gen g2=ranking1>=9&ranking1<=16
gen g3=ranking1>=17
foreach x in size{
qui reg `x'
outreg2  using summ1,  excel dec(3)  noaster append
qui reg `x' if g1==1
outreg2  using summ1,  excel dec(3)  noaster append
qui reg `x' if g2==1
outreg2  using summ1,  excel dec(3)  noaster append
qui reg `x' if g3==1
outreg2  using summ1,  excel dec(3)  noaster append
}

*Calculate standard deviations of school cohort sizes
preserve
collapse (sd) size
save sum11.dta, replace
restore

preserve
keep if g1==1
collapse (sd) size
save sum21.dta, replace
restore

preserve
keep if g2==1
collapse (sd) size
save sum31.dta, replace
restore

preserve
keep if g3==1
collapse (sd) size
save sum41.dta, replace
restore
clear

*Survey Data
*Summary Statistics - Matched Survey Data by School Selectivity

use "$dir2/summary_stats.dta", clear

*focus on long term sample BSSEE cohorts 1987-2002 (about 25-40 years old when surveyed)
keep if face_bslc==1&bssee_cohort<2003

joinby csec_secondary_sch_code1 using "$dir2/barbados_rank_revealed.dta", unm(m)
gen g1=ranking1>=1&ranking1<=8
gen g2=ranking1>=9&ranking1<=16
gen g3=ranking1>=17


*calculate means for survey data
!erase summ_main.xls
!erase summ_main.txt 
foreach x in  long_sd {
egen `x'a=std(`x')
}

foreach x in years_educ  h_uni2  mang_pro gross_main q9_26c baby1_18 med_ins dental q5_03a  {
qui reg `x' [pw=weight]
outreg2  using summ_main [pw=weight],  excel dec(3)  noaster append
qui reg `x' if g1==1 
outreg2  using summ_main [pw=weight],  excel dec(3)  noaster append
qui reg `x' if g2==1 
outreg2  using summ_main [pw=weight],  excel dec(3)  noaster append
qui reg `x' if g3==1 
outreg2  using summ_main [pw=weight],  excel dec(3)  noaster append
}

foreach x in  long_sda {
qui reg `x' 
outreg2  using summ_main ,  excel dec(3)  noaster append
qui reg `x' if g1==1 
outreg2  using summ_main ,  excel dec(3)  noaster append
qui reg `x' if g2==1 
outreg2  using summ_main ,  excel dec(3)  noaster append
qui reg `x' if g3==1 
outreg2  using summ_main ,  excel dec(3)  noaster append
}

*calculate standard deviations for survey data
preserve
collapse (sd) years_educ  h_uni2  mang_pro gross_main q9_26c baby1_18 med_ins dental q5_03a long_sda
save summ_main1.dta, replace
restore

preserve
keep if g1==1
collapse (sd) years_educ  h_uni2  mang_pro gross_main q9_26c baby1_18 med_ins dental q5_03a long_sda
save summ_main2.dta, replace
restore

preserve
keep if g2==1
collapse (sd) years_educ  h_uni2  mang_pro gross_main q9_26c baby1_18 med_ins dental q5_03a long_sda
save summ_main3.dta, replace
restore

preserve
keep if g3==1
collapse (sd) years_educ  h_uni2  mang_pro gross_main q9_26c baby1_18 med_ins dental q5_03a long_sda
save summ_main4.dta, replace
restore
clear


**************************************************************
*Table 2, Panel A. Test for density discontinuity across cutoffs
*****************************************************************

*This database contains the stacked database described in Section IV of the main text 
*please refer to the instructions document for details on how to request access to the database

use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

*test for differential density accross cutoffs for the population (+/- 0.75 SD from cutoff)

rddensity rco if (rco>=-23&rco<=23&(rco~=0))

/*

Computing data-driven bandwidth selectors.

RD Manipulation Test using local polynomial density estimation.

Cutoff c =      0.000 | Left of c  Right of c            Number of obs =       264289
----------------------+----------------------            Model         = unrestricted
        Number of obs |    185564       78725            BW method     =         comb
   Eff. Number of obs |     28948       23118            Kernel        =   triangular
 Order loc. poly. (p) |         2           2            VCE method    =    jackknife
         Order BC (q) |         3           3
   Bandwidths (hl,hr) | estimated   estimated
     Bandwidth values |     3.747       3.278

Running variable: rco.
---------------------------------------------
               Method |       T        P>|T|
----------------------+----------------------
Robust Bias-Corrected |   -0.8541      0.3930
---------------------------------------------

*/

*test for differential density accross cutoffs for the full matched survey sample

rddensity rco if face_bslc==1 &bssee_cohort<2003

/*
Computing data-driven bandwidth selectors.

RD Manipulation Test using local polynomial density estimation.

Cutoff c =      0.000 | Left of c  Right of c            Number of obs =         5610
----------------------+----------------------            Model         = unrestricted
        Number of obs |      4754         856            BW method     =         comb
   Eff. Number of obs |      1208         557            Kernel        =   triangular
 Order loc. poly. (p) |         2           2            VCE method    =    jackknife
         Order BC (q) |         3           3
   Bandwidths (hl,hr) | estimated   estimated
     Bandwidth values |    14.272      10.054

Running variable: rco.
---------------------------------------------
               Method |       T        P>|T|
----------------------+----------------------
Robust Bias-Corrected |   -0.9015      0.3673
---------------------------------------------

*/


***************************************************************************************************************
*Table 2, Panel B
***************************************************************************************************************
*RF effects on predicted outcomes
clear all
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear

set matsize 11000

foreach var in y10  z9    {
xi: reg `var'  i.bssee_sex*i.bssee_yob  i.bssee_sex*i.bssee_mob i.bssee_sex*i.parish_g i.bssee_sex*peer_score_st_prim i.bssee_sex*peer_score_c1 i.bssee_sex*peer_score_c2 i.bssee_sex*peer_score_c3 i.bssee_sex*peer_score_c4  
predict `var'_pred if e(sample), xb
}

foreach var in long_sd {
xi: reg `var' i.bssee_sex*i.bssee_yob  i.bssee_sex*i.bssee_mob i.bssee_sex*i.parish_g  i.bssee_sex*peer_score_st_prim i.bssee_sex*peer_score_c1 i.bssee_sex*peer_score_c2 i.bssee_sex*peer_score_c3 i.bssee_sex*peer_score_c4  if bssee_cohort<2003 & face_bslc==1 [pw= weight]
predict `var'_pred if e(sample), xb
}

!erase predict.xml
!erase predict.txt 

*Look at administrative with long-term sample
keep if bssee_cohort<2003 
global pred_adm "y10 z9"

foreach x in $pred_adm{

qui reghdfe `x'_pred rco rco2 rco3 rcoi rco2i rco3i above if rco>=-23&rco<=23&(rco~=0), absorb( fixed_effect ) cluster(id_bssee )
outreg2 above using predict,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'_pred  zrco* zabovef zabovenf  if (face_bslc==1|(face_bslc==0&rco>=-23&rco<=23&(rco~=0))) [pw= weight], absorb( fixed_effect  ) cluster(id_bssee )
	qui lincom zabovef-zabovenf
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 zabovef zabovenf using predict,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*Keep long-term survey data
keep if bssee_cohort<2003 & face_bslc==1

foreach x in long_sd{

qui reghdfe `x'_pred rco rco2 rco3 rcoi rco2i rco3i above if (face_bslc==1) [pw= weight], absorb( fixed_effect ) cluster(id_bssee )
outreg2 above using predict,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}

***************************************************************************************************************
*Table 2, Panels C, D, and E
***************************************************************************************************************

cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

!erase school.xml
!erase school.txt 

*First stage

keep if bssee_cohort<2003
foreach x in in_sch1 {

qui reghdfe `x'  zrco* zabovef zabovenf  if ((face_bslc==1)|(face_bslc==0&rco>=-23&rco<=23&(rco~=0))) [pw= weight], absorb(parish_g fixed_effect  ) cluster(id_bssee )
	qui lincom zabovef-zabovenf
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 zabovenf zabovef using school,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  zrco* zabovef zabovenf  if ((face_bslc==1)|(face_bslc==0&rco>=-23&rco<=23&(rco~=0))) [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
	qui lincom zabovef-zabovenf
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 zabovenf zabovef using school,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}

*school environments
global school "peer_score_st cv_sch1 enrolment herf"

foreach x in $school{

qui reghdfe `x'  zrco* (zin_sch1nf zin_sch1f=zabovef zabovenf)  if (face_bslc==1|(face_bslc==0&rco>=-23&rco<=23&(rco~=0))) [pw= weight], absorb(parish_g fixed_effect  ) cluster(id_bssee )
	qui lincom zin_sch1nf-zin_sch1f
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 zin_sch1nf zin_sch1f using school,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  zrco* (zin_sch1nf zin_sch1f=zabovef zabovenf)  if (face_bslc==1|(face_bslc==0&rco>=-23&rco<=23&(rco~=0))) [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
	qui lincom zin_sch1nf-zin_sch1f
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 zin_sch1nf zin_sch1f using school,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}

*survey response rate
foreach x in face_bslc {

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if rco>=-23&rco<=23&(rco~=0), absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using school,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if rco>=-23&rco<=23&(rco~=0), absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 in_sch1 using school,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}

*observations
foreach x in in_sch1 {
qui reg `x' if (rco>=-23&rco<=23&(rco~=0))
outreg2 using school,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reg `x' if (face_bslc==1)
outreg2 using school,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}

***************************************************************************************************************
*Table 3, CSEC, CAPE, and Survey outcomes
***************************************************************************************************************
*CSEC outcomes
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

global csec "y1  y10"

!erase csec.xml
!erase csec.txt 


**Look at effects using cohorts for which full CAPE data is available (bssee_cohort>=1998 & bssee_cohort<=2009); +/- 0.75 SD from cutoff 
keep if rco>=-23&rco<=23&(rco~=0)&(bssee_cohort>=1998 & bssee_cohort<=2009)

foreach x in $csec{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using csec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
outreg2 in_sch1 using csec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using csec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in y1 {
qui reg `x' 
outreg2 using csec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using csec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using csec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}

*CAPE outcomes
global cape "z1   z9"

!erase cape.xml
!erase cape.txt 


foreach x in $cape{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using cape,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
outreg2 in_sch1 using cape,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using cape,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in z1 {
qui reg `x' 
outreg2 using cape,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using cape,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using cape,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


* Educational Attainment + Labor Market + Health + Long-Term (Summary Indexes)

cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
keep if face_bslc==1 & bssee_cohort<2003 

!erase adult2.xls
!erase adult2.txt 

foreach x in long_sd educ_att_sd lmk_sd health_sd{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using adult2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee )
outreg2 in_sch1 using adult2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using adult2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}


*observations
foreach x in long_sd {
qui reg `x' 
outreg2 using adult2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using adult2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using adult2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


*Mechanisms
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
keep if face_bslc==1 & bssee_cohort<2003 

!erase mech.xls
!erase mech.txt 

*vocational training
foreach x in h_tech{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee )
outreg2 in_sch1 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}
*observations
foreach x in h_tech{
qui reg `x' 
outreg2 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


*social networks

foreach x in q9_26c{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee )
outreg2 in_sch1 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}
*observations
foreach x in q9_26c{
qui reg `x' 
outreg2 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


*teen motherhood
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
keep if face_bslc==1 & bssee_cohort<2003 
drop if female==0

*Ages ~26-41 when surveyed
global teen_preg "baby1_17 baby1_18 "


foreach x in $teen_preg {

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 in_sch1 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}
*observations
foreach x in baby1_17 {
qui reg `x' if female==1
outreg2 using mech,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


*************************************
*Appendix Table 1: Survey Representativeness
**************************************

use "$dir2/summary_stats.dta", clear
cd "$dir2"

gen mob_1_3=(mob_1==1| mob_2==1| mob_3==1)
gen mob_4_6=(mob_4==1| mob_5==1| mob_6==1)
gen mob_7_9=(mob_7==1| mob_8==1| mob_9==1)
gen mob_10_12=(mob_10==1| mob_11==1| mob_12==1)

global demo1 "female mob_1_3 mob_4_6 mob_7_9 mob_10_12 peer_score_c1 peer_score_c2 peer_score_c3 peer_score_c4 peer_score_c5 peer_score_c6 peer_score_c7 peer_score_c8 peer_score_c9" 
global demo2 "par_1 par_2 par_3 par_4 par_5 par_6 par_7 par_8 par_9 par_10 par_11" 
global demo3 "y1 y3 y5 y10"
global demo4 "z1 z10 z11 z9" 
!erase rep.xls
!erase rep.txt 

*means
gen no_face= face_bslc==0
foreach x in $demo1 $demo2 $demo3 $demo4{
qui reg `x' no_face face_bslc  [pw= weight], nocons
outreg2 no_face face_bslc using rep, excel noaster dec(3)   append
*test for equality of means controlling for cohort fixed effects
qui xi: reg `x' no_face face_bslc i.bssee_cohort i.parish_g [pw= weight], nocons
qui test no_face==face_bslc
outreg2 no_face face_bslc using rep,  excel noaster dec(3) adds(p-val, r(p))  append
}

*standard deviations
preserve
keep if no_face ==1
collapse (sd) $demo1 $demo2 $demo3 $demo4 
save sumr1.dta, replace
restore

preserve
keep if face_bslc ==1
collapse (sd) $demo1 $demo2 $demo3 $demo4 
save sumr2.dta, replace
restore

*observations
foreach x in y1 z1  {
qui reg `x' if no_face ==1
outreg2 using rep, excel noaster dec(3)   append
qui reg `x' if face_bslc ==1
outreg2 using rep, excel noaster dec(3)   append
}

clear


***************************************************************************************************************
*Appendix Table 2: 2SLS Effects on Secondary and Tertiary Examinations - Alternative Samples
***************************************************************************************************************
*CSEC
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

global csec "y1 y3 y5 y10"

!erase app1.xml
!erase app1.txt 


**Effects using BSSEE cohorts 1987-2002 (+/- 0.75 SD from cutoff) 
keep if rco>=-23&rco<=23&(rco~=0)&(bssee_cohort<2003)

foreach x in $csec{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
outreg2 in_sch1 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  ) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in y1 {
qui reg `x' 
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}

*Matched survey data only using BSSEE cohorts 1987-2002
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

keep if face_bslc==1 & bssee_cohort<2003

foreach x in $csec{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) [pw=weight], absorb(parish_g fixed_effect ) cluster(id_bssee)
outreg2 in_sch1 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) [pw=weight], absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 in_sch1 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  [pw=weight], absorb(parish_g fixed_effect  ) cluster(id_bssee)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  [pw=weight], absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in y1 {
qui reg `x' 
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


*CAPE using BSSEE cohorts 1998-2002 (+/- 0.75 SD from cutoff) 
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

global cape "z1  z10 z11 z9"

*Use only cohorts bssee_cohort<2003 (26-41 years at survey)
keep if rco>=-23&rco<=23&(rco~=0) & bssee_cohort<2003 


foreach x in $cape{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
outreg2 in_sch1 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  ) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in z1 {
qui reg `x' 
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using app1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}



***************************************************************************************************************
*Appendix Table 3: Reduced Form Estimates on Baseline Characteristics
***************************************************************************************************************
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
cd "$dir2"
set more off
*focus on BSSEE cohorts 1987-2002 (long term sample)
keep if bssee_cohort<2003

set more off
!erase spec.xls
!erase spec.txt 

global demo1 "mob_1 mob_2 mob_3 mob_4 mob_5 mob_6 mob_7 mob_8 mob_9 mob_10 mob_11 mob_12" 
global demo2 "peer_score_c1 peer_score_c2 peer_score_c3 peer_score_c4 peer_score_c5 peer_score_c6 peer_score_c7 peer_score_c8 peer_score_c9 "
global demo3 "par_1 par_2 par_3 par_4 par_5 par_6 par_7 par_8 par_9 par_10 par_11" 

foreach x in $demo1 $demo2 $demo3 {
qui reghdfe `x' above rco rco2 rco3 rcoi rco2i rco3i if rco>=-23&rco<=23&(rco~=0), absorb(fixed_effect) cluster(id_bssee )
outreg2 above using spec,  excel dec(3) append
qui reghdfe `x' above rco rco2 rco3 rcoi rco2i rco3i if rco>=-23&rco<=23&(rco~=0)&female==1, absorb(fixed_effect) cluster(id_bssee )
outreg2 above using spec,  excel dec(3) append
qui reghdfe `x' above rco rco2 rco3 rcoi rco2i rco3i if rco>=-23&rco<=23&(rco~=0)&female==0, absorb(fixed_effect) cluster(id_bssee )
outreg2 above using spec,  excel dec(3) append

qui reghdfe `x' above rco rco2 rco3 rcoi rco2i rco3i if (face_bslc==1) [pw=weight], absorb(fixed_effect) cluster(id_bssee )
outreg2 above using spec,  excel dec(3) append
qui reghdfe `x' above rco rco2 rco3 rcoi rco2i rco3i if (face_bslc==1&female==1) [pw=weight], absorb(fixed_effect) cluster(id_bssee )
outreg2 above using spec,  excel dec(3) append
qui reghdfe `x' above rco rco2 rco3 rcoi rco2i rco3i if (face_bslc==1&female==0) [pw=weight], absorb(fixed_effect) cluster(id_bssee )
outreg2 above using spec,  excel dec(3) append
}

*observations
foreach x in par_1 {
qui reg `x' if rco>=-23&rco<=23&(rco~=0)
outreg2 using spec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if rco>=-23&rco<=23&(rco~=0)&female==1
outreg2 using spec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if rco>=-23&rco<=23&(rco~=0)&female==0
outreg2 using spec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if (face_bslc==1)
outreg2 using spec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if (face_bslc==1&female==1)
outreg2 using spec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if (face_bslc==1&female==0)
outreg2 using spec,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}

***************************************************************************************************************
*Appendix Table 4: Reduced Form Estimates on Predicted Outcomes
***************************************************************************************************************
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear

set matsize 11000

foreach var in y1 y3 y5 y10  z1  z10 z11 z9   {
xi: reg `var'  i.bssee_sex*i.bssee_yob  i.bssee_sex*i.bssee_mob i.bssee_sex*i.parish_g i.bssee_sex*peer_score_st_prim i.bssee_sex*peer_score_c1 i.bssee_sex*peer_score_c2 i.bssee_sex*peer_score_c3 i.bssee_sex*peer_score_c4  
predict `var'_pred if e(sample), xb
}

foreach var in educ_att_sd lmk_sd health_sd long_sd {
xi: reg `var' i.bssee_sex*i.bssee_yob  i.bssee_sex*i.bssee_mob i.bssee_sex*i.parish_g  i.bssee_sex*peer_score_st_prim i.bssee_sex*peer_score_c1 i.bssee_sex*peer_score_c2 i.bssee_sex*peer_score_c3 i.bssee_sex*peer_score_c4 if bssee_cohort<2003 & face_bslc==1 [pw= weight]
predict `var'_pred if e(sample), xb
}

!erase predict1.xml
!erase predict1.txt 

*Use same cohorts assesed for Main Tables on CSEC and CAPE (1998-2009) - Cohorts with full CAPE data
global pred_csec "y1 y3 y5 y10  "
global pred_cape "z1 z10 z11 z9"

preserve
keep if (bssee_cohort>=1998 & bssee_cohort<=2009)

foreach x in $pred_csec $pred_cape{

qui reghdfe `x'_pred rco rco2 rco3 rcoi rco2i rco3i above if rco>=-23&rco<=23&(rco~=0), absorb( fixed_effect ) cluster(id_bssee )
outreg2 above using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append


qui reghdfe `x'_pred  srco* sabove*  if rco>=-23&rco<=23&(rco~=0) , absorb(fixed_effect  ) cluster(id_bssee)
	qui lincom sabovef-sabovem
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sabovef sabovem using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}

*observations
foreach x in y1{
qui reg `x' if rco>=-23&rco<=23&(rco~=0)
outreg2 using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if rco>=-23&rco<=23&(rco~=0)&female==1
outreg2 using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if rco>=-23&rco<=23&(rco~=0)&female==0
outreg2 using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}

restore

*Keep long-term survey data
keep if bssee_cohort<2003 & face_bslc==1

foreach x in long_sd educ_att_sd lmk_sd health_sd {

qui reghdfe `x'_pred rco rco2 rco3 rcoi rco2i rco3i above if (face_bslc==1) [pw= weight], absorb( fixed_effect ) cluster(id_bssee)
outreg2 above using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'_pred  srco* sabove*  if (face_bslc==1) [pw= weight], absorb( fixed_effect  ) cluster(id_bssee)
	qui lincom sabovef-sabovem
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sabovef sabovem using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}

*observations
foreach x in long_sd_pred {
qui reg `x' 
outreg2 using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using predict1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}


***************************************************************************************************************
*Appendix Table 5: 2SLS Effects on CSEC and CAPE Outcomes
***************************************************************************************************************
*CSEC
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

global csec "y1 y3 y5 y10"

!erase csec2.xml
!erase csec2.txt 

**Look at effects using cohorts for which full CAPE data is available (bssee_cohort>=1998 & bssee_cohort<=2009); +/- 0.75 SD from cutoff 
keep if rco>=-23&rco<=23&(rco~=0)&(bssee_cohort>=1998 & bssee_cohort<=2009)


foreach x in $csec{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect ) cluster(id_bssee rco)
outreg2 in_sch1 using csec2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee rco)
outreg2 in_sch1 using csec2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee rco)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using csec2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in y1 {
qui reg `x' 
outreg2 using csec2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using csec2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using csec2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


*CAPE

global cape "z1 z10 z11 z9"

!erase cape2.xml
!erase cape2.txt 


foreach x in $cape{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect ) cluster(id_bssee rco)
outreg2 in_sch1 using cape2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee rco)
outreg2 in_sch1 using cape2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee rco)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using cape2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in z1 {
qui reg `x' 
outreg2 using cape2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using cape2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using cape2,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}

***************************************************************************************************************
*Appendix Table 6: 2SLS Effects on Educational Attainment and Labor Market Indicators
***************************************************************************************************************

****************************************
*Adult Educational Attainment 
****************************************

cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
keep if face_bslc==1 & bssee_cohort<2003 

global adult "years_educ h_uni2 "

!erase adult.xls
!erase adult.txt 

foreach x in $adult  {

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using adult,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee )
outreg2 in_sch1 using adult,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  ) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using adult,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using adult,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}
*observations
foreach x in h_uni2 {
qui reg `x' 
outreg2 using adult,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using adult,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using adult,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}

****************************************
*Adult Main Occupation and Labor Market Outcomes
****************************************

gen out_lf=inlf==0
replace out_lf=. if inlf==.
*Ages ~26-41 when surveyed
global adult1 "emp unemp out_lf mang_pro lgross_main"


!erase adult1.xls
!erase adult1.txt 
replace mang_pro=. if employed==0


foreach x in $adult1{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using adult1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee )
outreg2 in_sch1 using adult1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  ) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using adult1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4) cluster(id_bssee )
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using adult1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}


*observations
foreach x in emp  mang_pro{
qui reg `x' 
outreg2 using adult1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using adult1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using adult1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


***************************************************************************************************************
*Appendix Table 7: 2SLS Effects on Health Indicators
***************************************************************************************************************
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
keep if face_bslc==1 & bssee_cohort<2003 

global health "q5_03a med_ins dental normal over_ob under"

*All sample
!erase health.xls
!erase health.txt 

*26-41 at survey

*weighted
foreach x in $health{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect ) cluster(id_bssee)
outreg2 in_sch1 using health,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2  ) cluster(id_bssee)
outreg2 in_sch1 using health,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  ) cluster(id_bssee)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using health,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  c1 c2 ) cluster(id_bssee)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using health,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


}

*observations
foreach x in q5_03a normal{
qui reg `x' 
outreg2 using health,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using health,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using health,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


***************************************************************************************************************
*Appendix Table 8: Sensitivity of 2SLS Effects on Main Outcomes to Alternative BSSEE Polynomial Specifications
***************************************************************************************************************

****************************************
*Secondary School Academic Achievement (CSEC)
****************************************
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

global csec "y1  y10"

!erase csec_s.xml
!erase csec_s.txt 

**Look at effects using cohorts for which full CAPE data is available (bssee_cohort>=1998 & bssee_cohort<=2009); +/- 0.75 SD from cutoff 
keep if rco>=-23&rco<=23&(rco~=0)&(bssee_cohort>=1998 & bssee_cohort<=2009)

*All
foreach x in $csec {
qui reghdfe `x' rco  rcoi  (in_sch1=above)  , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 in_sch1  using csec_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x' rco rco2  rcoi rco2i  (in_sch1=above)  , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 in_sch1  using csec_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above)  , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 in_sch1  using csec_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

}

*by gender
foreach x in $csec{
qui reghdfe `x'  srcof srcom srcoif srcoim ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using csec_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x'  srcof srcom srcoif srcoim srco2f srco2m srco2if srco2im ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using csec_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x'  srcof srcom srcoif srcoim srco2f srco2m srco2if srco2im srco3f srco3m srco3if srco3im ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using csec_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

}


****************************************
*Post-Secondary School Academic Achievement (CAPE)
****************************************

global cape "z1  z9"

!erase cape_s.xml
!erase cape_s.txt 

*All
foreach x in $cape {
qui reghdfe `x' rco  rcoi  (in_sch1=above)  , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 in_sch1  using cape_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x' rco rco2  rcoi rco2i  (in_sch1=above)  , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 in_sch1  using cape_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above)  , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 in_sch1  using cape_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

}

*By gender
foreach x in $cape{
qui reghdfe `x'  srcof srcom srcoif srcoim ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using cape_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x'  srcof srcom srcoif srcoim srco2f srco2m srco2if srco2im ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using cape_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x'  srcof srcom srcoif srcoim srco2f srco2m srco2if srco2im srco3f srco3m srco3if srco3im ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using cape_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

}

******************************
* Summary Indexes 
******************************

cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
keep if face_bslc==1 & bssee_cohort<2003 
!erase index_s.xls
!erase index_s.txt 
*All
foreach x in long_sd educ_att_sd lmk_sd health_sd{
qui reghdfe `x'  rco  rcoi    (in_sch1=above) [pw= weight] , absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 in_sch1  using index_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x'  rco rco2 rcoi rco2i   (in_sch1=above) [pw= weight] , absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 in_sch1  using index_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x'  rco rco2 rco3  rcoi rco2i rco3i   (in_sch1=above) [pw= weight] , absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 in_sch1  using index_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

}

*By gender
foreach x in long_sd educ_att_sd lmk_sd health_sd{
qui reghdfe `x'  srcof srcom srcoif srcoim ( sin_sch1f sin_sch1m =sabove*) [pw= weight] , absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using index_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x'  srcof srcom srcoif srcoim srco2f srco2m srco2if srco2im ( sin_sch1f sin_sch1m =sabove*)  [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using index_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

qui reghdfe `x'  srcof srcom srcoif srcoim srco2f srco2m srco2if srco2im srco3f srco3m srco3if srco3im ( sin_sch1f sin_sch1m =sabove*) [pw= weight] , absorb(parish_g fixed_effect  c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 sin_sch1f sin_sch1m using index_s,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3)  append

}

***************************************************************************************************************
*Appendix Table 9: 2SLS Effects on Main Outcomes (two-way clustering at the individual and BSSEE score levels)
***************************************************************************************************************
*CSEC
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

global csec "y1  y10"

!erase csec1.xml
!erase csec1.txt 


**Look at effects using cohorts for which full CAPE data is available (bssee_cohort>=1998 & bssee_cohort<=2009); +/- 0.75 SD from cutoff 
keep if rco>=-23&rco<=23&(rco~=0)&(bssee_cohort>=1998 & bssee_cohort<=2009)


foreach x in $csec{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect ) cluster(id_bssee rco)
outreg2 in_sch1 using csec1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee rco)
outreg2 in_sch1 using csec1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  ) cluster(id_bssee rco)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using csec1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee rco)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using csec1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in y1 {
qui reg `x' 
outreg2 using csec1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using csec1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using csec1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


*CAPE

global cape "z1   z9"

!erase cape1.xml
!erase cape1.txt 


foreach x in $cape{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect ) cluster(id_bssee rco)
outreg2 in_sch1 using cape1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) , absorb(parish_g fixed_effect c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee rco)
outreg2 in_sch1 using cape1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  ) cluster(id_bssee rco)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using cape1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append


qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  , absorb(parish_g fixed_effect  c1 c2 c3 c4 c5 c6 c7 c8 c9) cluster(id_bssee rco)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using cape1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append
}

*observations
foreach x in z1 {
qui reg `x' 
outreg2 using cape1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using cape1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using cape1,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}

cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 
keep if face_bslc==1 & bssee_cohort<2003 

!erase adult3.xls
!erase adult3.txt 

foreach x in long_sd educ_att_sd lmk_sd health_sd{

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect ) cluster(id_bssee rco)
outreg2 in_sch1 using adult3,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee rco)
outreg2 in_sch1 using adult3,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  ) cluster(id_bssee rco)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using adult3,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

qui reghdfe `x'  srco* ( sin_sch1f sin_sch1m =sabove*)  if (face_bslc==1) [pw= weight], absorb(parish_g fixed_effect  c1 c2 c3 c4) cluster(id_bssee rco)
	qui lincom sin_sch1f-sin_sch1m
    qui local tstat=r(estimate)/r(se)
    qui local pval = tprob(r(df), abs(`tstat'))
outreg2 sin_sch1f sin_sch1m using adult3,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) adds(diff, r(estimate), sd, r(se), p-val,`pval')  append

}


*observations
foreach x in long_sd {
qui reg `x' 
outreg2 using adult3,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==1
outreg2 using adult3,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
qui reg `x' if female==0
outreg2 using adult3,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append
}


***************************************************************************************************************
*Appendix Table 10: 2SLS Effects on Fertility
***************************************************************************************************************
cd "$dir2"
use "$dir2/BSSEE_CSEC_CAPE_BARBADOS_applicants_reduced.dta", clear 

*correct total fertility
replace fertility=0 if baby_ever==0&fertility==.

*insert extra outcomes of fertility
joinby hhid bslc_id using nmigrants.dta, unm(m)
tab _merge

keep if face_bslc==1 & bssee_cohort<2003 
drop if female==0
drop if bssee_cohort==1989

*Ages ~26-41 when surveyed
global fert "baby1_25 baby_ever fertility"

!erase fert.xls
!erase fert.txt 


foreach x in $fert {
qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) , absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using fert,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) , absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee )
outreg2 in_sch1 using fert,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}

*observations
foreach x in fertility {
qui reg `x' 
outreg2  using fert,  excel noaster dec(3) append
}


keep if face_bslc==1 & bssee_cohort<=1992 
foreach x in baby_ever fertility {
qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) , absorb(parish_g fixed_effect ) cluster(id_bssee )
outreg2 in_sch1 using fert,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) , absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 in_sch1 using fert,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}

*observations
foreach x in fertility {
qui reg `x' 
outreg2  using fert,  excel noaster dec(3) append
}


keep if face_bslc==1 & bssee_cohort<=1991 
foreach x in baby_ever fertility {
qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) , absorb(parish_g fixed_effect ) cluster(id_bssee)
outreg2 in_sch1 using fert,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

qui reghdfe `x' rco rco2 rco3 rcoi rco2i rco3i (in_sch1=above) if (face_bslc==1) , absorb(parish_g fixed_effect c1 c2 c3 c4 ) cluster(id_bssee)
outreg2 in_sch1 using fert,  excel alpha(0.01, 0.05, 0.1, 0.15) symbol(***,**,*,+) dec(3) append

}

*observations
foreach x in fertility {
qui reg `x' 
outreg2  using fert,  excel noaster dec(3) append
}

