clear all
global dir1 "Data_folder"
global dir2 "Output_folder"

cd "$dir2"

*******************************************************
*outcomes from face to face survey
*******************************************************

use "$dir1\RT002_Public.dta", clear

*highest educ 
gen h_tech=q3_27==6 | q3_27==8
gen h_uni2=(q3_27>=10 & q3_27<=13)
foreach x in h_tech h_uni2 {
replace `x'=. if q3_27==.
}


*calculate years of education
gen years_educ=0
replace years_educ=5 if q3_27==2
replace years_educ=5 if q3_27==3
replace years_educ=10 if (q3_27>=4 & q3_27<=5)
replace years_educ=11 if q3_27==6
replace years_educ=15 if q3_27==7
replace years_educ=11 if q3_27==8
replace years_educ=15 if q3_27==9
replace years_educ=18 if q3_27==10
replace years_educ=19 if q3_27==11
replace years_educ=20 if q3_27==12
replace years_educ=23 if q3_27==13
replace years_educ=. if q3_27==14 | q3_27==.

*current main occupation
gen emp=q9_04==1
gen unemp=q9_04==2

gen inlf=emp==1|unemp==1
replace inlf=. if emp==.&unemp==.

*type of job: Manager or Professional
gen mang_pro=q9_13>=1&q9_13<=2

*Referred to current job by secondary social network
foreach x in q9_26c {
replace `x'=0 if `x'==. & q9_04==1
}

*income
gen gross_main=q10_02a/2
replace gross_main=. if q10_02a==0
gen lgross_main=ln(gross_main)

*teen motherhood/fertility
gen yob=substr(q1_05,7,4)
destring yob, replace
replace yob=2001 if yob==1
replace yob=1967 if yob==967
replace yob=2005 if yob==1005
replace yob=1964 if yob==1664
replace yob=1957 if yob==1857
 
gen yobf=substr( q6_04_1b ,7,4) 
destring yobf, replace
replace yobf=2004 if yobf==1004
replace yobf=1983 if yobf==1083
replace yobf=1988 if yobf==2988

gen agef=yobf-yob
replace agef=. if agef<10

forval x=17/25{
gen baby_`x'=agef<=`x'
replace baby_`x'=. if agef==.
}
forval x=17/25{
gen baby1_`x'=baby_`x'
replace baby1_`x'=0 if q6_01==2&baby_`x'==.
}
forval x=17/25{
drop baby_`x'
}

gen baby_ever=q6_01==1
replace baby_ever=. if q6_01==.

gen fertility=q6_02
replace fertility=0 if baby_ever==0&fertility==.

*Body mass index and obesity
*convert poounds to kilograms
replace q5_01o=0 if q5_01o==.
gen t1=q5_01o/16
gen pounds=t1+q5_01p
gen kilograms=pounds/2.2046
*centimeters to meters
gen meters=q5_02/100
*bmi
gen bmi=kilograms/(meters*meters)
*obesity
gen under=bmi<18.5
replace under=. if bmi==.
gen normal=bmi>=18.5&bmi<25
replace normal=. if bmi==.
gen over=bmi>=25&bmi<30
replace over=. if bmi==.
gen obese=bmi>=30
replace obese=. if bmi==.
gen over_ob=over==1|obese==1
replace over_ob=. if bmi==.

*physical activity: weekly gym
foreach x in q5_03a {
replace `x'=0 if `x'==.
}

*preventive health
gen dental=q5_05==1
replace dental=. if q5_05==.
gen med_ins=q5_29==1
replace med_ins=. if q5_29==.

keep weight hhid id emp unemp inlf  years_educ h_tech h_uni2 mang_pro q9_26c gross_main lgross_main baby1_17 baby1_18 baby1_25 ///
baby_ever fertility under normal  over_ob q5_03a dental med_ins

ren id bslc_id

save survey.dta, replace
clear

**Once the survey data is matched with the administrative data, calculate the summary indexes only with the matched sample

foreach x in years_educ h_uni2 emp mang_pro lgross_main dental  med_ins  q5_03a  normal{
bysort bssee_cohort: egen mean_`x'=mean(`x')
bysort bssee_cohort: egen sd_`x'=sd(`x')
gen new_`x'=(`x'-mean_`x')/sd_`x'
drop mean_`x' sd_`x'
}

egen educ_att_sd=rowmean( new_years_educ  new_h_uni2)
egen lmk_sd=rowmean( new_emp  new_mang_pro  new_lgross_main)
egen health_sd=rowmean( new_dental  new_med_ins  new_q5_03a new_normal)
egen long_sd=rowmean( new_years_educ  new_h_uni2 new_emp  new_mang_pro  new_lgross_main new_dental  new_med_ins  new_q5_03a new_normal)


