* ANALYSIS OF EFFECTS SIZES TO PRODUCE A META-ANALYSIS OF EDUCATIONAL INTERVENTIONS.
* IT USES A PROCEDURE SIMILAR TO THE ONE USED IN THE SKILLSBANK (AS OF 20-FEB-2019).
* THERE ARE 3 DO FILES INVOLVED IN THIS ANALYSIS. 


* THIS IS THE SECOND DO FILE.
* THIS DO FILE, CALLED AGGREGATE.DO, AGGREATE THE DATA SO THAT WE END UP WITH A SUMMARY EFFECT FOR EACH EVALUATION



clear all
set more off



foreach type in "preferred" "elite" /*"charter"*/ {

	* 0. READ DATA

	use "$z/evaluations_effects.dta", clear
	
	keep if effect == "`type'"
	
	* THE UNIT OF OBSERVATION IS: EVALUATION-SUBSAMPLE-OUTCOME-TEST
	* WE WILL AGGREATE THE EFFECTS AND STANDARD ERRORS SO THAT THE UNIT OF OBSERVATION IS EVALUATION.

	* NOTE: ALTERNATIVELY, WE COULD SELECT ALL THE MATH TESTS AND THEN GET ONE SUMMARY EFFECT FOR MATH
	* AND THEN USE THE ORIGINAL DATA SET SELECTING ALL THE READING TESTS AND THEN GET A SUMMARY EFFECT FOR READING




	* 1. COMBINE TESTS AND GET EFFECTS AT OUTCOME LEVEL

	* WE COMPUTE SUMMARY EFFECT SIZE FOR EACH COMBINATION: EVALUATION-SUBSAMPLE-OUTCOME
	* WE AGGREGATE EFFECTS AS SIMPLE AVERAGES. 
	* FOR AGGREGATION OF STANDARD ERRORS WE ASSUME CORRELATION 0.5

	bys evaluation subsample outcome: gen count = _n 
	bys evaluation subsample outcome: egen aux1 = max(count) 
	tab aux1 

	* NOTE: WE HAVE AT MOST 4 EFFECTS PER OUTCOME



	* 1.1. AGGREGATE EFFECT SIZES 

	* ONE EFFECT PER OUTCOME 

	gen effect1=.
	replace effect1=coef if count[_n]==1 & count[_n+1]!=2 & count[_n+2]!=3 & count[_n+3]!=4


	* TWO EFFECTS PER OUTCOME 

	gen effect2=.
	replace effect2=(coef+coef[_n+1])/2 if count[_n]==1 & count[_n+1]==2 & count[_n+2]!=3 & count[_n+3]!=4


	* THREE EFFECTS PER OUTCOME 

	gen effect3=.
	replace effect3=(coef+coef[_n+1]+coef[_n+2])/3 if count[_n]==1 & count[_n+1]==2 & count[_n+2]==3 & count[_n+3]!=4


	* FOUR EFFECTS PER OUTCOME 
	gen effect4=.
	replace effect4=(coef+coef[_n+1]+coef[_n+2]+coef[_n+3])/4 if count[_n]==1 & count[_n+1]==2 & count[_n+2]==3 & count[_n+3]==4


	* 1.2. AGGREGATE STANDARD ERRORS  

	* ONE EFFECT PER OUTCOME 

	gen se1=.
	replace se1 = se if count[_n]==1 & count[_n+1]!=2 & count[_n+2]!=3 & count[_n+3]!=4


	* TWO EFFECTS PER OUTCOME

	gen se2=.
	gen aux2 = 0.25*se^2+0.25*se[_n+1]^2 + 2*0.5*0.5*0.5*se*se[_n+1] ///
		 if count[_n]==1 & count[_n+1]==2 & count[_n+2]!=3 & count[_n+3]!=4
	replace se2 = aux2 ^0.5 


	* THREE EFFECTS PER OUTCOME 

	gen se3=.
	gen aux3 = (1/3)^2*(se^2+se[_n+1]^2+se[_n+2]^2+2*0.5*se*se[_n+1]+2*0.5*se*se[_n+2]+2*0.5*se[_n+1]*se[_n+2]) ///
		 if count[_n]==1 & count[_n+1]==2 & count[_n+2]==3 & count[_n+3]!=4
	replace se3= aux3^0.5 


	* FOUR EFFECTS PER OUTCOME 

	gen se4=.
	gen aux4=(1/4)^2 *(se[_n]^2+se[_n+1]^2+se[_n+2]^2+se[_n+3]^2+se[_n]*se[_n+1]+se[_n]*se[_n+2]+se[_n]*se[_n+3]+se[_n+1]*se[_n+2]+se[_n+1]*se[_n+3]+se[_n+2]*se[_n+3]) ///
		if count[_n]==1 & count[_n+1]==2 & count[_n+2]==3 & count[_n+3]==4
	replace se4= aux4^0.5 




	* 1.3. AGGREGATE NUMBER OF OBSERVATIONS


	* ONE EFFECT PER OUTCOME 

	gen n1=.
	replace n1=n ///
			if count[_n]==1 & count[_n+1]!=2 & count[_n+2]!=3 & count[_n+3]!=4 & count[_n+4]!=5 & count[_n+5]!=6 ///
			& count[_n+6]!=7 & count[_n+7]!=8 & count[_n+8]!=9 & count[_n+9]!=10


	* TWO EFFECTS PER OUTCOME 

	gen n2=.
	replace n2=(n+n[_n+1])/2 ///
		   if count[_n]==1 & count[_n+1]==2 & count[_n+2]!=3 & count[_n+3]!=4 & count[_n+4]!=5 & count[_n+5]!=6 ///
		   & count[_n+6]!=7 & count[_n+7]!=8 & count[_n+8]!=9 & count[_n+9]!=10
		   
		   
		   
	* THREE EFFECTS PER OUTCOME 

	gen n3=.
	replace n3=(n+n[_n+1]+n[_n+2])/3 ///
		   if count[_n]==1 & count[_n+1]==2 & count[_n+2]==3 & count[_n+3]!=4 & count[_n+4]!=5 & count[_n+5]!=6 ///
		   & count[_n+6]!=7 & count[_n+7]!=8 & count[_n+8]!=9 & count[_n+9]!=10	    		
			
		
	* FOUR EFFECTS PER OUTCOME 

	gen n4=.
	replace n4=(n+n[_n+1]+n[_n+2]+n[_n+3])/4 if ///
		   count[_n]==1 & count[_n+1]==2 & count[_n+2]==3 & count[_n+3]==4 & count[_n+4]!=5 & count[_n+5]!=6 ///
		   & count[_n+6]!=7 & count[_n+7]!=8 & count[_n+8]!=9 & count[_n+9]!=10	    





	* 1.4. GET FINAL EFFECT SIZES AND THEIR STANDARD ERRORS

	egen n_test = rowtotal (n1 n2 n3 n4)
	egen effect_test = rowtotal (effect1 effect2 effect3 effect4)
	egen se_test = rowtotal (se1 se2 se3 se4)
	keep if count==1


	drop se1 se2 se3 se4 effect1 effect2 effect3 effect4 n1 n2 n3 n4 
	drop aux2 aux3 aux4 aux1
	drop count







	* 2.  COMBINE OUTCOMES AND GET EFFECTS AT EVALUATION-SUBSAMPLE LEVEL

	* IN THIS STEP WE GET ONE SINGLE EFFECT FOR EACH COMBINATION EVALUATION-SUBSAMPLE. 

	* AT THIS POINT, WE MAY HAVE THE FOLLOWING COMBINATIONS OF OUTCOMES FOR ANY GIVEN PAIR EVALUATION-SUBSAMPLE: 

			
			
	*(i) 	MATH, LANGUAGE, AVERAGE 		
	*(ii) 	LANGUAGE, AVERAGE 		
	*(iii)	MATH, AVERAGE 		
	*(iv) 	AVERAGE 		
	*(v)  	MATH, LANGUAGE 		
	*(vi) 	MATH 	
	*(vii)	LANGUAGE  		
			
			
	* WE PROCEDE AS FOLLOWS: 		
			
	* CASES (i)-(iv): WE KEEP THE EFFECT FOR AVERAGE TEST SCORE.		
	* CASE (v): WE COMPUTE AVERAGE TEST SCOCRE OF MATH AND LANGUAGE. FOR AGGREGATION OF STANDARD ERRORS WE ASSUME CORRELATION 0.5.		
	* CASES (vi), (vii): WE KEEP THE EFFECTS AS THEY ARE. 		


	sort evaluation subsample outcome




	* CASES (i)-(iv): IMPUTE SUMMARY TEST SCORE, IF IT WAS REPORTED IN EVALUATION

	foreach outcome in "3" "102" {
		preserve
		
			if `outcome' == 3 keep if outcome==1 | outcome==2 | outcome==3
			if `outcome' == 102 keep if outcome==`outcome'
			
				if _N>0 {
				if `outcome' == 3 {
					bys evaluation subsample : egen aux1 = max(outcome) 
					tab aux1

					gen effect3 = effect_test if outcome == 3
					gen se3 = se_test if outcome == 3
					gen n3 = n_test if outcome == 3

					* CASE (v): COMBINE MATH AND LANGUAGE IF SUMMARY TEST SCORE WAS NOT REPORTED

					bys evaluation subsample : gen count = _n  
					bys evaluation subsample : egen aux_count = max(count)  


					* EFFECT SIZE

					gen effect2 =0.5*effect_test+0.5*effect_test[_n+1] if outcome==1 & outcome[_n+1]==2 & evaluation==evaluation[_n+1] & subsample==subsample[_n+1] & aux_count!=3


					* SAMPLE SIZE

					gen n2 =0.5*n_test+0.5*n_test[_n+1] if outcome==1 & outcome[_n+1]==2 & evaluation==evaluation[_n+1] & subsample==subsample[_n+1] & aux_count!=3


					* STANDARD ERROR

					gen se2=.
					gen aux4 = 0.25*se_test^2+0.25*se_test[_n+1]^2 + 2*0.5*0.5*0.5*se_test*se_test[_n+1] if outcome==1 & outcome[_n+1]==2 & evaluation==evaluation[_n+1] & subsample==subsample[_n+1] & aux_count!=3
					replace se2 = aux4 ^0.5



					* CASES (vi), (vii): IMPUTE THE EFFECT SIZE FOR THE GIVEN TEST SCORE IF ONLY ONE, EITHER MATH OR LANGUAGE, SCORE IS REPORTED

					* EFFECT SIZE

					gen effect1 =effect_test if aux_count==1 & count == 1 


					* STANDARD ERROR

					gen se1 =se_test if aux_count==1 & count == 1 


					* SAMPLE SIZE

					gen n1 =n_test if aux_count==1 & count == 1 





					* GET FINAL EFFECT SIZES AND THEIR STANDARD ERRORS

					gen effect_subsample = effect3
					replace effect_subsample = effect1 if effect3==.
					replace effect_subsample = effect2 if effect_subsample==.


					gen se_subsample = se3
					replace se_subsample = se1 if se3==.
					replace se_subsample = se2 if se_subsample==.


					gen n_subsample = n3
					replace n_subsample = n1 if n3==.
					replace n_subsample = n2 if n_subsample==.




					keep if effect_subsample !=. 


					drop aux* count effect1 effect2 effect3 se1 se2 se3 n1 n2 n3
					drop effect_test se_test n_test

					replace coef = effect_subsample
					replace se = se_subsample
					replace n = n_subsample

					drop effect_subsample se_subsample n_subsample
					}

				if `outcome' >= 4 { //Not math+reading (which have to be selected)
					replace coef = effect_test
					replace se = se_test
					}





				* 3. COMBINE SUBSAMPLES AND GET EFFECTS AT EVALUATION LEVEL

				* IN THIS STEP WE COMBINE EFFECTS WITHIN EACH EVALUATION ACROSS INDEPENDENT SUBSAMPLES. 


				* EFFECTS ARE COMBINED ACROSS INDEPENDENT SUBSAMPLES USING FIXED EFFECTS META-ANALYSIS APPROACH.


				bysort evaluation: gen count=_n
				egen aux_count=max(count),by(evaluation)


				gen weight=1/se^2
				gen coef2=coef*weight


				egen weight_t=sum(weight),by(evaluation)
				egen coef2_t=sum(coef2),by(evaluation)


				gen coef3=coef2_t/weight_t


				gen var2=1/weight_t
				gen se2=var^.5




				* FOR AGGREGATION OF SAMPLE SIZES: 
				* SINCE WE HAVE INDEPENDENT SUMSAMPLES, THE NUMBER OF OBSERVATIONS AT EVALUATION LEVEL IS 
				* A SUM OF OBSERVATIONS IN DIFFERENT SUBSAMPLES. 

				egen n1 = total (n), by(evaluation)


				keep if count==1


				replace coef=coef3 if aux_count>1
				replace n=n1 if aux_count>1
				replace se=se2 if aux_count>1

				drop count aux_count weight coef2 weight_t coef2_t coef3 var2 se2 n1

				keep PaperID evaluation country year n itt coef se design
				order PaperID evaluation country year n itt coef se design
				
				gen outcome = `outcome'
				}
			tempfile temp_`outcome'
			save `temp_`outcome'', replace
		restore
		}


	* KEEP RELEVANT VARIABLES


	drop if outcome == 1 | outcome==2 | outcome==3 | outcome == 102
	append using `temp_3'
	append using `temp_102'



	* SAVE FINAL DATASET WITH EFFECTS AGGREGATED AT EVALUATION LEVEL
	
	save "$z/evaluations_`type'.dta", replace 
	}
*
	
clear
foreach type in "preferred" "elite" /*"charter"*/  {
		* 1. READ THE DATA SET CONTAINING ONE EFFECT SIZE (AND A STANDARD ERROR) PER EVALUATION 
		append using "$z/evaluations_`type'.dta"
		}
*
keep if outcome==3

keep PaperID evaluation country design
bys PaperID evaluation: keep if _n==1

*Give new Paper ID given alphabetical order
preserve
	bys PaperID: keep if _n==1
	egen id1 = group(evaluation)
	tempfile id1 
	save `id1', replace
restore

merge m:1 PaperID using `id1', keep(master match) keepusing(id1)

*In case there is more than one evaluation per paper: give letters
bys PaperID : gen N=_N
bys PaperID (evaluation): gen id2=_n

*New Paper ID
gen id = string(id1)
replace id = "[" + id + "]" if N==1
replace id = "[" + id + "a" + "]" if N>1 & id2==1
replace id = "[" + id + "b" + "]" if N>1 & id2==2
replace id = "[" + id + "c" + "]" if N>1 & id2==3
replace id = "[" + id + "d" + "]" if N>1 & id2==4
replace id = "[" + id + "e" + "]" if N>1 & id2==5	

sort id1 id2

keep PaperID evaluation country design id1 id2 id 

tempfile new_id
save `new_id', replace

replace country = "United Kingdom" if country == "UK"
replace country = "Trinidad and Tobago" if country == "Trinidad y Tobago"
replace country = "USA (North Carolina)" if country == "USA (NC)"

replace design = "RD" if design == "RD-attended" | design == "RD-peers"
replace design = "Admission Lottery" if design == "lottery"

replace design = "RD & Admission Lottery" if evaluation == "Bui et al (2014)"

gen evaluation_country = evaluation + " - " + country + " [" + design + "]"

list PaperID evaluation_country id, sep(100)

clear
foreach type in "preferred" "elite" /*"charter"*/  {
		* 1. READ THE DATA SET CONTAINING ONE EFFECT SIZE (AND A STANDARD ERROR) PER EVALUATION 
		use "$z/evaluations_`type'.dta", clear
		merge m:1 PaperID evaluation using `new_id', keep(master match) keepusing(id1 id2 id) nogen
		save "$z/evaluations_`type'.dta", replace
		}
